@@ -4,11 +4,13 @@ var access_portal_8c =
     [ "client", "structclient.html", "structclient" ],
     [ "MEDIA_ROLE_ALL", "access-portal_8c.html#ab6ba62dd01f9aec27734739d325b016e", null ],
     [ "NAME", "access-portal_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "access-portal_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "SESSION_KEY", "access-portal_8c.html#a894b84c8f5ff621bf7f7ed71c990b651", null ],
     [ "media_role", "access-portal_8c.html#a053bc21ed148e82ee074f6d01dde9f24", [
       [ "MEDIA_ROLE_INVALID", "access-portal_8c.html#a053bc21ed148e82ee074f6d01dde9f24ac92d46c0f736870fe11b6a7ae07627da", null ],
       [ "MEDIA_ROLE_NONE", "access-portal_8c.html#a053bc21ed148e82ee074f6d01dde9f24aa390dc0572cb347164bc8ad5d5d3ed70", null ],
       [ "MEDIA_ROLE_CAMERA", "access-portal_8c.html#a053bc21ed148e82ee074f6d01dde9f24a081c0e79948c2010896f55c9a467d35b", null ]
     ] ],
+    [ "PW_LOG_TOPIC_STATIC", "access-portal_8c.html#a32cef58a621827e475f6e0c51cdfe973", null ],
     [ "sm_access_portal_start", "access-portal_8c.html#aa597625de3f7576c7624333e10714082", null ]
 ];
\ No newline at end of file
