@@ -5,6 +5,9 @@ var alsa_monitor_8c =
     [ "impl", "structimpl.html", "structimpl" ],
     [ "DEFAULT_JACK_SECONDS", "alsa-monitor_8c.html#adc1029d668c71c4ecd39890f743e93d1", null ],
     [ "NAME", "alsa-monitor_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "NAME", "alsa-monitor_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "alsa-monitor_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "SESSION_CONF", "alsa-monitor_8c.html#ab416de5c5659fccccf89c7bbaa3b165b", null ],
+    [ "PW_LOG_TOPIC_STATIC", "alsa-monitor_8c.html#a32cef58a621827e475f6e0c51cdfe973", null ],
     [ "sm_alsa_monitor_start", "alsa-monitor_8c.html#aa9ef70bd6d282ae0ff2689934010f16e", null ]
 ];
\ No newline at end of file
