@@ -6,6 +6,8 @@ var bluez_endpoint_8c =
     [ "device", "structdevice.html", "structdevice" ],
     [ "impl", "structimpl.html", "structimpl" ],
     [ "NAME", "bluez-endpoint_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "bluez-endpoint_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "SESSION_KEY", "bluez-endpoint_8c.html#a894b84c8f5ff621bf7f7ed71c990b651", null ],
+    [ "PW_LOG_TOPIC_STATIC", "bluez-endpoint_8c.html#a32cef58a621827e475f6e0c51cdfe973", null ],
     [ "sm_bluez5_endpoint_start", "bluez-endpoint_8c.html#ac8f85443572299fdd9d070721951b23e", null ]
 ];
\ No newline at end of file
