@@ -5,6 +5,8 @@ var bluez_monitor_8c =
     [ "impl", "structimpl.html", "structimpl" ],
     [ "FEATURES_CONF", "bluez-monitor_8c.html#a3a3aad305d922f0cdd8fee2152b6f16b", null ],
     [ "NAME", "bluez-monitor_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "bluez-monitor_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "SESSION_CONF", "bluez-monitor_8c.html#ab416de5c5659fccccf89c7bbaa3b165b", null ],
+    [ "PW_LOG_TOPIC_STATIC", "bluez-monitor_8c.html#a32cef58a621827e475f6e0c51cdfe973", null ],
     [ "sm_bluez5_monitor_start", "bluez-monitor_8c.html#a3193b64b101000ce73b4c86060e963b2", null ]
 ];
\ No newline at end of file
