@@ -22,19 +22,19 @@ var group__spa__support =
     [ "spa_dbus_connection", "structspa__dbus__connection.html", [
       [ "add_listener", "structspa__dbus__connection.html#a2e21fc21219047d9bdc8e1994a23acea", null ],
       [ "destroy", "structspa__dbus__connection.html#a1b0a0400c311d50b764f100b4b50bf8f", null ],
-      [ "get", "structspa__dbus__connection.html#a63734afd162c784b905cb30903a537f6", null ],
+      [ "get", "structspa__dbus__connection.html#a684f175f4839121d8c976c50ca273303", null ],
       [ "version", "structspa__dbus__connection.html#a8b89c910cd288a5e1d2af8216568a3a6", null ]
     ] ],
     [ "spa_dbus_methods", "structspa__dbus__methods.html", [
-      [ "get_connection", "structspa__dbus__methods.html#a012a7bcc11a6685ab1f35939fde0a72f", null ],
+      [ "get_connection", "structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28", null ],
       [ "version", "structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434", null ]
     ] ],
     [ "spa_i18n", "structspa__i18n.html", [
       [ "iface", "structspa__i18n.html#a4ca10c865fe33ffff4fd9abb9265c0f8", null ]
     ] ],
     [ "spa_i18n_methods", "structspa__i18n__methods.html", [
-      [ "ntext", "structspa__i18n__methods.html#a86a65ea95402cc177242ca24f3ea9080", null ],
-      [ "text", "structspa__i18n__methods.html#aa6a71edc71368a5cd323536ae38e836e", null ],
+      [ "ntext", "structspa__i18n__methods.html#a884391486c3277069fb8ee2f9d754234", null ],
+      [ "text", "structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675", null ],
       [ "version", "structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b", null ]
     ] ],
     [ "spa_loop", "structspa__loop.html", [
@@ -75,11 +75,11 @@ var group__spa__support =
       [ "version", "structspa__loop__control__methods.html#aa66e2f92b352ef1ae10b591f11086340", null ]
     ] ],
     [ "spa_loop_utils_methods", "structspa__loop__utils__methods.html", [
-      [ "add_event", "structspa__loop__utils__methods.html#adea85519bdd59342d7012603d39b73fe", null ],
-      [ "add_idle", "structspa__loop__utils__methods.html#a7b3ff020ed94d62852752d55b057b08d", null ],
-      [ "add_io", "structspa__loop__utils__methods.html#ae838730dc82a9f5100539437b963480d", null ],
-      [ "add_signal", "structspa__loop__utils__methods.html#a0db325151cd1a27e3f6f163c6d46c5d9", null ],
-      [ "add_timer", "structspa__loop__utils__methods.html#a9a94dbdf882ed804b36f041327b0410a", null ],
+      [ "add_event", "structspa__loop__utils__methods.html#aea2ab7bb653eef26373295fafbe048fc", null ],
+      [ "add_idle", "structspa__loop__utils__methods.html#a79ae6123ff0f20029d4e722053b49a11", null ],
+      [ "add_io", "structspa__loop__utils__methods.html#adc8b3b97121c94a824307117dad02989", null ],
+      [ "add_signal", "structspa__loop__utils__methods.html#af9604ab5944fce7539516ff227ddc2f9", null ],
+      [ "add_timer", "structspa__loop__utils__methods.html#ab24aa861875574691b833aaaf356a2ad", null ],
       [ "destroy_source", "structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913", null ],
       [ "enable_idle", "structspa__loop__utils__methods.html#a4466703d3ee6e18abc89bafea2b0c0ed", null ],
       [ "signal_event", "structspa__loop__utils__methods.html#aa30b5933fcadb8606772d95471ec7a05", null ],
@@ -87,6 +87,14 @@ var group__spa__support =
       [ "update_timer", "structspa__loop__utils__methods.html#abc9a0d7bb777e2c892343b1ca5a6d37d", null ],
       [ "version", "structspa__loop__utils__methods.html#aefb69d2a6ad30b352b4414401a55f3e7", null ]
     ] ],
+    [ "spa_plugin_loader", "structspa__plugin__loader.html", [
+      [ "iface", "structspa__plugin__loader.html#a17501870cdaf04804cde83d541a31a61", null ]
+    ] ],
+    [ "spa_plugin_loader_methods", "structspa__plugin__loader__methods.html", [
+      [ "load", "structspa__plugin__loader__methods.html#ac03d77f832ee680b4a1b68acdbcc05d4", null ],
+      [ "unload", "structspa__plugin__loader__methods.html#aa91d4ff3f01f2d7c38a066b3d8bc98ca", null ],
+      [ "version", "structspa__plugin__loader__methods.html#ae2de2d15c28cf425552bb3aa6ca0bad4", null ]
+    ] ],
     [ "spa_system", "structspa__system.html", [
       [ "iface", "structspa__system.html#a87fdaae85b7f2321bd10b05a3c9f9b54", null ]
     ] ],
@@ -122,7 +130,7 @@ var group__spa__support =
     ] ],
     [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", [
       [ "acquire_rt", "structspa__thread__utils__methods.html#a6423900a0115ed260e5d4b15f24285f5", null ],
-      [ "create", "structspa__thread__utils__methods.html#af0e80ed5c979807b0326def25690beef", null ],
+      [ "create", "structspa__thread__utils__methods.html#a22e5fb8af7bfdb9fe503f2562f5ed122", null ],
       [ "drop_rt", "structspa__thread__utils__methods.html#a67cf4dee89855ce72ad3c48184e1ca01", null ],
       [ "get_rt_range", "structspa__thread__utils__methods.html#a93b7072cec0d4898712b33c7a6808767", null ],
       [ "join", "structspa__thread__utils__methods.html#a32030849999e51af737dad5d2761c927", null ],
@@ -258,6 +266,7 @@ var group__spa__support =
     [ "SPA_TYPE_INTERFACE_Loop", "group__spa__support.html#ga5ea06c2ace410d56b97b466704b3ded7", null ],
     [ "SPA_TYPE_INTERFACE_LoopControl", "group__spa__support.html#gacafe7661d00fa945b3c4f3471ef3e2c3", null ],
     [ "SPA_TYPE_INTERFACE_LoopUtils", "group__spa__support.html#ga3e3c897298f750f7847db45e0785bb43", null ],
+    [ "SPA_TYPE_INTERFACE_PluginLoader", "group__spa__support.html#gade61903a8bd06ae84ad4fa6d6f4035d0", null ],
     [ "SPA_TYPE_INTERFACE_System", "group__spa__support.html#ga54a93b686738ba2115a8cac54202031f", null ],
     [ "SPA_TYPE_INTERFACE_ThreadUtils", "group__spa__support.html#ga6680e7f42845ca460cdaa93abd568e02", null ],
     [ "SPA_VERSION_CPU", "group__spa__support.html#ga6cd931ac7d37bf2a2e4b311cc562cf38", null ],
@@ -266,6 +275,7 @@ var group__spa__support =
     [ "SPA_VERSION_LOOP", "group__spa__support.html#ga50c88c59a795523063c7f48e517fce74", null ],
     [ "SPA_VERSION_LOOP_CONTROL", "group__spa__support.html#gaf08e046c937b0d412b56b0cccbeeebea", null ],
     [ "SPA_VERSION_LOOP_UTILS", "group__spa__support.html#gae3db9595657af4faae90e6d844291fa7", null ],
+    [ "SPA_VERSION_PLUGIN_LOADER", "group__spa__support.html#ga4ad7f76d73f45e3b813415d8eef9652a", null ],
     [ "SPA_VERSION_SYSTEM", "group__spa__support.html#gad8592bcc0072a7f3e01c1c599c31a59a", null ],
     [ "SPA_VERSION_THREAD_UTILS", "group__spa__support.html#ga4f716da417d838544df4e82f4670b79c", null ],
     [ "spa_invoke_func_t", "group__spa__support.html#gab59a4a2bc60d5c26983a0e0edabc6617", null ],
@@ -280,11 +290,13 @@ var group__spa__support =
       [ "SPA_DBUS_TYPE_SYSTEM", "group__spa__support.html#gga39128520ce2167eb64279fc23e617fa0a5fdca2872c84184d6a5ca0701726d229", null ],
       [ "SPA_DBUS_TYPE_STARTER", "group__spa__support.html#gga39128520ce2167eb64279fc23e617fa0a4645a44a9d5954b882e7a3c23672fed8", null ]
     ] ],
-    [ "spa_dbus_get_connection", "group__spa__support.html#ga2a7849e38452deb37cc3ae69ec1436df", null ],
-    [ "spa_i18n_ntext", "group__spa__support.html#ga6c4193d7a1a93d013b9733d66907cc7f", null ],
-    [ "spa_i18n_text", "group__spa__support.html#gabbca29d87ce5fc4b00b5be260a6c4a6f", null ],
+    [ "spa_dbus_get_connection", "group__spa__support.html#ga65dee1ac21fd250bba7fbfe30b94543d", null ],
+    [ "spa_i18n_ntext", "group__spa__support.html#ga6308906880809caec1ec322e65909f59", null ],
+    [ "spa_i18n_text", "group__spa__support.html#gab1de4a438f825c82bf302b42044dce37", null ],
+    [ "spa_plugin_loader_load", "group__spa__support.html#gaf2597e1ad1db500c9a8f7b850e1c1243", null ],
+    [ "spa_plugin_loader_unload", "group__spa__support.html#ga8cabaa285c9e5d41260de5f74d8cecf0", null ],
     [ "spa_thread_utils_acquire_rt", "group__spa__support.html#gaf8856d51b5173c7404fe9ba0b468e216", null ],
-    [ "spa_thread_utils_create", "group__spa__support.html#ga54a876fc9108bddc11237c0c8cff2286", null ],
+    [ "spa_thread_utils_create", "group__spa__support.html#ga557081e739fe47934c2c2ac7093af754", null ],
     [ "spa_thread_utils_drop_rt", "group__spa__support.html#ga8d4d667abd5d5128cd9885d6cc862aa7", null ],
     [ "spa_thread_utils_get_rt_range", "group__spa__support.html#ga070bc3ef2e89b7560d9d4382b4359716", null ],
     [ "spa_thread_utils_join", "group__spa__support.html#gaa2f318d1cb2652f24ec0d2c0e1e95556", null ]
