@@ -3,7 +3,8 @@ var impl_port_8c =
     [ "result_port_params_data", "structresult__port__params__data.html", "structresult__port__params__data" ],
     [ "param_filter", "structparam__filter.html", "structparam__filter" ],
     [ "NAME", "impl-port_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
-    [ "pw_context_create_port", "group__pw__impl__port.html#gaae2224ae65300630f7b88542a0fa85a9", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "impl-port_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
+    [ "pw_context_create_port", "group__pw__impl__port.html#ga006aa900c4a192b709b19916e31b782d", null ],
     [ "pw_impl_port_add", "group__pw__impl__port.html#ga56cd7301e2c55e93f032c0e82562465a", null ],
     [ "pw_impl_port_add_listener", "group__pw__impl__port.html#gacb4744ca242716128f55b470e6a4b734", null ],
     [ "pw_impl_port_destroy", "impl-port_8c.html#a7c3fcad0c458ce17185733e1b3788f3e", null ],
@@ -12,20 +13,21 @@ var impl_port_8c =
     [ "pw_impl_port_for_each_param", "impl-port_8c.html#ae1591911d79a209cdb10dfb259a3f4ae", null ],
     [ "pw_impl_port_get_direction", "group__pw__impl__port.html#ga9e553c2ffc8a8a70b325521af90a0cf9", null ],
     [ "pw_impl_port_get_id", "group__pw__impl__port.html#gac28520f534eaa508ff1ea14122f842a9", null ],
-    [ "pw_impl_port_get_info", "group__pw__impl__port.html#gad9ac2b5b1cc595f2d71ed221523e7e70", null ],
-    [ "pw_impl_port_get_node", "group__pw__impl__port.html#ga79b1192c4a309f804a00ad72c971c4de", null ],
-    [ "pw_impl_port_get_properties", "group__pw__impl__port.html#ga2c84428d2c6a261544e0d777cf556a27", null ],
-    [ "pw_impl_port_get_user_data", "impl-port_8c.html#a20c4276dd2fee85fefbfda8eb32588f6", null ],
-    [ "pw_impl_port_init_mix", "impl-port_8c.html#ac400cbc5454a4b991253bd3775d7a561", null ],
+    [ "pw_impl_port_get_info", "group__pw__impl__port.html#gaf3c7764d7f42e9f4df666dfd7499e387", null ],
+    [ "pw_impl_port_get_node", "group__pw__impl__port.html#ga78f3d10b5af9c245095d9a22e59ceeb1", null ],
+    [ "pw_impl_port_get_properties", "group__pw__impl__port.html#ga5682619e17eb12d4bd4c7d70e985e08c", null ],
+    [ "pw_impl_port_get_user_data", "impl-port_8c.html#added9639eee8e91a882c0c397c5720b1", null ],
+    [ "pw_impl_port_init_mix", "impl-port_8c.html#a46d1a736c95c1cbad591493cd3aa081b", null ],
     [ "pw_impl_port_is_linked", "group__pw__impl__port.html#ga2f4e8293872dd04eabb559ed7f331f73", null ],
     [ "pw_impl_port_recalc_latency", "impl-port_8c.html#ab97d1e101e60e760ec5edd2c3cfde5d9", null ],
     [ "pw_impl_port_register", "impl-port_8c.html#a1c4649f9eb37286e346138547e69eadd", null ],
-    [ "pw_impl_port_release_mix", "impl-port_8c.html#afbd81ad92d0bb4095759805cdb2e46b9", null ],
-    [ "pw_impl_port_set_mix", "impl-port_8c.html#af3ed1f5b440e9cd9abbceab69a3e0f1f", null ],
-    [ "pw_impl_port_set_param", "impl-port_8c.html#a3140935daffeac3cb316bb81e062cded", null ],
+    [ "pw_impl_port_release_mix", "impl-port_8c.html#ab600c86ce5b41b99449fe4a88acb08ca", null ],
+    [ "pw_impl_port_set_mix", "impl-port_8c.html#abc530ba61ee4e4b71f692a4c9e75aa0e", null ],
+    [ "pw_impl_port_set_param", "impl-port_8c.html#a2c61155fe653f379393d3b5089542430", null ],
     [ "pw_impl_port_unlink", "impl-port_8c.html#a50bf3c733ffb016e75a87b4133cda66f", null ],
     [ "pw_impl_port_update_info", "impl-port_8c.html#a1217c97aae9a167558afdb3fa43532fe", null ],
     [ "pw_impl_port_update_properties", "group__pw__impl__port.html#ga0a0c6321011b667f97d93cff9d0006d1", null ],
     [ "pw_impl_port_update_state", "impl-port_8c.html#a7d8911cc4854ad9d167c44783e4c9e24", null ],
-    [ "pw_impl_port_use_buffers", "impl-port_8c.html#ad69f1724f300cfa404d7e472af904d84", null ]
+    [ "pw_impl_port_use_buffers", "impl-port_8c.html#a58c297e4b28b4c2f6b80329ada84585b", null ],
+    [ "PW_LOG_TOPIC_EXTERN", "impl-port_8c.html#a1585dfb49b0af42891440ece1dda5dee", null ]
 ];
\ No newline at end of file
