@@ -14,5 +14,7 @@ var module_filter_chain_8c =
     [ "MAX_PORTS", "module-filter-chain_8c.html#a40ad70cc6e2125af9340a4bc26a83764", null ],
     [ "MAX_SAMPLES", "module-filter-chain_8c.html#a78f316da3a87bf72cb1647786b64bf0e", null ],
     [ "NAME", "module-filter-chain_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
-    [ "pipewire__module_init", "module-filter-chain_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ]
+    [ "PW_LOG_TOPIC_DEFAULT", "module-filter-chain_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
+    [ "pipewire__module_init", "module-filter-chain_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
+    [ "PW_LOG_TOPIC_STATIC", "module-filter-chain_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ]
 ];
\ No newline at end of file
