@@ -7,10 +7,13 @@ var module_protocol_native_8c =
     [ "LOCK_SUFFIX", "module-protocol-native_8c.html#a11aa03fdbf1a2680335dcaa0c73f25e3", null ],
     [ "LOCK_SUFFIXLEN", "module-protocol-native_8c.html#a55f0760f271ff025b986de41b1e9f11e", null ],
     [ "NAME", "module-protocol-native_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "module-protocol-native_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "SO_PEERSEC", "module-protocol-native_8c.html#a9f479b0932bb9ff546564502e2d58ad4", null ],
-    [ "spa_debug", "module-protocol-native_8c.html#af340c4036f24d8e51d86d506a989319e", null ],
+    [ "spa_debug", "module-protocol-native_8c.html#a85dfce75df6a24fc0a29945ab03b1c86", null ],
     [ "UNIX_PATH_MAX", "module-protocol-native_8c.html#a7baab2aa5bf8eb14b6128e0f16634837", null ],
     [ "pipewire__module_init", "module-protocol-native_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
+    [ "PW_LOG_TOPIC", "module-protocol-native_8c.html#a25d870f60f991a83eae379650774a19c", null ],
+    [ "PW_LOG_TOPIC", "module-protocol-native_8c.html#a11707a769aeeb8add7eccfef17816321", null ],
     [ "pw_protocol_native0_init", "module-protocol-native_8c.html#a34b109a63760042abedc466d9e3182cf", null ],
     [ "pw_protocol_native_init", "module-protocol-native_8c.html#ae7322af7d4a3649ca07abb32463cbb88", null ]
 ];
\ No newline at end of file
