@@ -1,12 +1,14 @@
 var module_pulse_tunnel_8c =
 [
     [ "impl", "structimpl.html", "structimpl" ],
-    [ "DEFAULT_LATENCY_USEC", "module-pulse-tunnel_8c.html#ae6e3e571584fb00b0f14398e5dcd30bb", null ],
+    [ "DEFAULT_LATENCY_MSEC", "module-pulse-tunnel_8c.html#a8dabb367f1d158070ceb984522220ee0", null ],
     [ "MODE_CAPTURE", "module-pulse-tunnel_8c.html#a2d3dfe80720c65b109d9abf184d4d0dc", null ],
     [ "MODE_PLAYBACK", "module-pulse-tunnel_8c.html#a6807eaa1097c375218dafc41f3ee9aaa", null ],
     [ "MODULE_USAGE", "module-pulse-tunnel_8c.html#acc847625d3fc806b4f854350e9c8a9d9", null ],
     [ "NAME", "module-pulse-tunnel_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "module-pulse-tunnel_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "RINGBUFFER_MASK", "module-pulse-tunnel_8c.html#af8802823370996072398958767f811e9", null ],
     [ "RINGBUFFER_SIZE", "module-pulse-tunnel_8c.html#a3119c147393ef51aa50af08b3172a358", null ],
-    [ "pipewire__module_init", "module-pulse-tunnel_8c.html#af9c48c3d1d3b67cb1baf7755425985c7", null ]
+    [ "pipewire__module_init", "module-pulse-tunnel_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
+    [ "PW_LOG_TOPIC_STATIC", "module-pulse-tunnel_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ]
 ];
\ No newline at end of file
