@@ -2,10 +2,14 @@ var module_rt_8c =
 [
     [ "impl", "structimpl.html", "structimpl" ],
     [ "DEFAULT_NICE_LEVEL", "module-rt_8c.html#ae2718343d4f129ab6a5d35f1dba32968", null ],
+    [ "DEFAULT_POLICY", "module-rt_8c.html#a67972eda1492b6dac2f752c3a5731e7d", null ],
     [ "DEFAULT_RT_PRIO", "module-rt_8c.html#acb9b1867509d3e8e03f23517d31a4204", null ],
     [ "DEFAULT_RT_TIME_HARD", "module-rt_8c.html#a78c40b5d551118920115deed33bfa04f", null ],
     [ "DEFAULT_RT_TIME_SOFT", "module-rt_8c.html#a77e209d634e7e9926cda9cd155925b3d", null ],
     [ "MODULE_USAGE", "module-rt_8c.html#acc847625d3fc806b4f854350e9c8a9d9", null ],
+    [ "NAME", "module-rt_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "module-rt_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "RLIMIT_RTTIME", "module-rt_8c.html#a6a40cd11db1a42f781cf1bf94b9b6215", null ],
-    [ "pipewire__module_init", "module-rt_8c.html#af9c48c3d1d3b67cb1baf7755425985c7", null ]
+    [ "pipewire__module_init", "module-rt_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
+    [ "PW_LOG_TOPIC_STATIC", "module-rt_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ]
 ];
\ No newline at end of file
