@@ -7,12 +7,15 @@ var module_rtkit_8c =
     [ "DEFAULT_RT_TIME_HARD", "module-rtkit_8c.html#a78c40b5d551118920115deed33bfa04f", null ],
     [ "DEFAULT_RT_TIME_SOFT", "module-rtkit_8c.html#a77e209d634e7e9926cda9cd155925b3d", null ],
     [ "MODULE_USAGE", "module-rtkit_8c.html#acc847625d3fc806b4f854350e9c8a9d9", null ],
+    [ "NAME", "module-rtkit_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "module-rtkit_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
     [ "RLIMIT_RTTIME", "module-rtkit_8c.html#a6a40cd11db1a42f781cf1bf94b9b6215", null ],
     [ "RTKIT_OBJECT_PATH", "module-rtkit_8c.html#a27b7573eece84d30d0c45e5a652dfd03", null ],
     [ "RTKIT_SERVICE_NAME", "module-rtkit_8c.html#a3813f1fb4540a58a5837e8ed7d79b514", null ],
-    [ "pipewire__module_init", "module-rtkit_8c.html#af9c48c3d1d3b67cb1baf7755425985c7", null ],
+    [ "pipewire__module_init", "module-rtkit_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
+    [ "PW_LOG_TOPIC_STATIC", "module-rtkit_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ],
     [ "pw_rtkit_bus_free", "module-rtkit_8c.html#aa9d6de323dca8f32a2938bc14c4c015d", null ],
-    [ "pw_rtkit_bus_get_system", "module-rtkit_8c.html#a8a8d15bfbef60eb905ee49830eb32dd1", null ],
+    [ "pw_rtkit_bus_get_system", "module-rtkit_8c.html#a912b98d5edfd5916750e16efd69671a2", null ],
     [ "pw_rtkit_get_max_realtime_priority", "module-rtkit_8c.html#a2b457cbc98233e0dafb7d0fa9647c60a", null ],
     [ "pw_rtkit_get_min_nice_level", "module-rtkit_8c.html#a37e687e0400222f9b100b0fd33f98ec5", null ],
     [ "pw_rtkit_get_rttime_usec_max", "module-rtkit_8c.html#a33def5d45c70c88cc6eb71a3c1958143", null ],
