@@ -25,16 +25,16 @@
 var NAVTREE =
 [
   [ "PipeWire", "index.html", [
-    [ "Overview", "page_overview.html", null ],
-    [ "PipeWire", "page_pipewire.html", "page_pipewire" ],
-    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
-    [ "Media Session", "page_media_session.html", "page_media_session" ],
     [ "API Documentation", "page_api.html", [
       [ "Core API", "page_api.html#page_core_api", null ],
       [ "Implementation API", "page_api.html#page_implementation_api", null ]
     ] ],
-    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
+    [ "Media Session", "page_media_session.html", "page_media_session" ],
+    [ "Overview", "page_overview.html", null ],
+    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
+    [ "PipeWire", "page_pipewire.html", "page_pipewire" ],
     [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
+    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
     [ "Modules", "modules.html", "modules" ],
     [ "Data Structures", "annotated.html", [
       [ "Data Structures", "annotated.html", "annotated_dup" ],
@@ -63,43 +63,32 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "access-flatpak_8c.html",
-"dbus_8h.html#a3b4641d430f6892c79f6a02284349dbf",
-"group__pw__client.html#ga1144b60d4d77eb5b5bda140e6dd31e13",
-"group__pw__filter.html",
-"group__pw__impl__device.html#ga5ad9e42ea1d048840b5ef3785ff5034d",
-"group__pw__keys.html#ga18a9e0e59cd1a02e6c444edae293f887",
-"group__pw__keys.html#gaedf51309856ddd63ceb49dd66f047f30",
-"group__pw__memblock.html#gga1daf40887c9a63347e9c59822287747aac3e5ceea50faacf9d2aac1670f07fd65",
-"group__pw__properties.html#gaf140f16cfea836559f783f942cfa247d",
-"group__pw__stream.html#gab2ef0e28a1e91816f8015ef9814d18f7",
-"group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea61da86daedb6b8a14a66d067d6a5f80b",
-"group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58",
-"group__spa__keys.html#ga5fe280d124abe3a56346781116908033",
-"group__spa__node.html#ga3d829ade49e9ca5053fc77ba57ea5b0f",
-"group__spa__param.html#ga24bd9414a34ba30e9c0f0ad99b86e427",
-"group__spa__param.html#gac453d82f4058f782084269adfdee4d6f",
-"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a92abe760ab85d38bf142d18a41e28089",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcae65a88bd9de18b87e5203f00e704eda7",
-"group__spa__param.html#ggaaa66f9e8b1228f1ef1f2630d8d9c5ab5a6d7c25839d6f085a19aa12ca93b2032c",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaab2a1b460a366ad936a33e4f8a1243087",
-"group__spa__param.html#ggaef4025eec20c863b29c7ae07bb3c8d44af7177480c59ea9898cbc421d8740681e",
-"group__spa__pod.html#ga6a89f83c7b14e392bcdaa3c1f2d736ab",
-"group__spa__pod.html#gaea71c973cc38a58e1efd3ab257278d72",
-"group__spa__support.html#gaab4122dc40f03111652545e70ee32b7c",
-"group__spa__utils.html#ga1454d578034f980cbb9f6980f73da335",
-"group__spa__utils.html#gac8080acabcd35c560a15df5e1801afa1",
-"latency-utils_8h.html#a0d0d7d22631ed4d31967a8b005ade6bb",
-"module-pulse-tunnel_8c.html#ae6e3e571584fb00b0f14398e5dcd30bb",
-"page_objects_design.html#autotoc_md100",
-"pod_2pod_8h_source.html",
-"structendpoint.html",
-"structimpl.html#ab3e2f70923316ba1971f4c451fd56cec",
-"structparam.html#a097d5385b4cce1a839a764a2b43c0323",
-"structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6",
-"structresource__data.html#a5e0db18b4c73cb00fb7ac001fe016198",
-"structspa__i18n__methods.html#aa6a71edc71368a5cd323536ae38e836e",
-"structspa__pod__control.html#adeb12535d89c6cfd05a27edf7c981e4e",
-"structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd"
+"control_8c.html#a2676d48aaa968bb77e06846004e0b9d0",
+"globals_eval_m.html",
+"group__pw__data__loop.html#gae566b4ae45ffa6127fa159e1289470d0",
+"group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd",
+"group__pw__pipewire.html#ga1bffd3e2e02f201486d7d9f17950e5eb",
+"group__pwtest.html#gab465d70253d093ecf30b9f67810c2c78",
+"group__spa__keys.html",
+"group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ab9fcd93a987a6206804df617ff988a3e",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586aada997439499d0288ea2d2e6154190bc",
+"group__spa__param.html#gga741ca54fc7f93308779660120bbed31eae880c12653ce2c55c21103c18c06b9e1",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea7be903e8544c911a3d6fa76f4d8286f1",
+"group__spa__pod.html#gaba57d08c0947c4ed640bc89be320723d",
+"group__spa__types.html#ga2262de66172c201319e7336253600f31",
+"group__spa__utils.html#gaf76607bd5d48aa7b41d693260a19b68e",
+"media-session_8c.html#a07366ec9560cbd0ed0155a85534711c3",
+"module-roc-source_8c.html",
+"page_spa_buffer.html",
+"proxy_8c.html#acae5a1b85f78c3a018d1e773dcc44372",
+"structfilter.html",
+"structimpl.html#af62a9f71ce3207d49054c6536e8f16a2",
+"structport.html#aa79c01e6ca01fe420eb8ae7a960e165e",
+"structpw__map.html#a6fc621171dbc57de8c44d26f639d2f1b",
+"structroute__info.html#a9595cb0b99e503d59658a24f9511a61a",
+"structspa__io__position.html#a6b6da4b94ab7924dda2007712ff2e8f1",
+"structspa__pod__id.html#a6313b9440a92ad53fa8cdd7a2902b817",
+"structsupport.html#a816cdf5c1f85d6d9b5d82e8ba5508864"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
