@@ -1,6 +1,7 @@
 var resource_8c =
 [
-    [ "NAME", "resource_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
+    [ "PW_LOG_TOPIC_DEFAULT", "resource_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
+    [ "PW_LOG_TOPIC_EXTERN", "resource_8c.html#aaf5e71d40c70d2aca609d2e96ef568ad", null ],
     [ "pw_resource_add_listener", "group__pw__resource.html#ga119a41be865f03ef8736977acba8a323", null ],
     [ "pw_resource_add_object_listener", "group__pw__resource.html#gaa2d8c1bd7008acbd8fe30e47e6c08d3f", null ],
     [ "pw_resource_destroy", "group__pw__resource.html#gab9e159d75b7efe39bd53b64055244092", null ],
@@ -8,16 +9,16 @@ var resource_8c =
     [ "pw_resource_errorf", "resource_8c.html#a7ae51a412dc9a4f69956f71858c88de1", null ],
     [ "pw_resource_errorf_id", "resource_8c.html#ae48db134f5926965f84d3684213b2b61", null ],
     [ "pw_resource_get_bound_id", "group__pw__resource.html#ga6006f7393419cb5c874398f2954ac1b4", null ],
-    [ "pw_resource_get_client", "group__pw__resource.html#ga2939579219c911b29702d145b9cfc1df", null ],
+    [ "pw_resource_get_client", "group__pw__resource.html#ga8baec43db135c6f71cf26b7b3e500361", null ],
     [ "pw_resource_get_id", "group__pw__resource.html#gaf8fe4859dd6826d5eb6c7e28f5519215", null ],
-    [ "pw_resource_get_marshal", "group__pw__resource.html#gaab37d37e596381fec6da22531f78d7bb", null ],
-    [ "pw_resource_get_object_listeners", "group__pw__resource.html#ga961e8d61d007ece23ae04afd08e320dc", null ],
+    [ "pw_resource_get_marshal", "group__pw__resource.html#ga9135836c3f3a0860261aee85ae6dcc3c", null ],
+    [ "pw_resource_get_object_listeners", "group__pw__resource.html#gae08cdf7d997595185d3e7ff0235a6305", null ],
     [ "pw_resource_get_permissions", "group__pw__resource.html#ga332bee9e00671e80bd1d897551aa065d", null ],
-    [ "pw_resource_get_protocol", "group__pw__resource.html#gac7d13ba52bc1796d4baca39ddc4a6f0c", null ],
-    [ "pw_resource_get_type", "group__pw__resource.html#ga6ae5c51e7cab79f755e36c8746973da3", null ],
-    [ "pw_resource_get_user_data", "group__pw__resource.html#gae022953f35be3767c44de0c43fa572e2", null ],
+    [ "pw_resource_get_protocol", "group__pw__resource.html#ga5f5b343c88d5274a6702755a6452cb40", null ],
+    [ "pw_resource_get_type", "group__pw__resource.html#gafc89e299d5a8ee7eb725e6b4994b61a6", null ],
+    [ "pw_resource_get_user_data", "group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04", null ],
     [ "pw_resource_install_marshal", "group__pw__resource.html#ga6000827e0dc8637b0538f75800c0f581", null ],
-    [ "pw_resource_new", "group__pw__resource.html#gae32b47d6f25f56678385b0c269e8c3e0", null ],
+    [ "pw_resource_new", "group__pw__resource.html#gaeb9ac77ab0c2ad96099396c64a4ffb92", null ],
     [ "pw_resource_ping", "group__pw__resource.html#ga9edff924e88ea8ae7d0b74065ad7415a", null ],
     [ "pw_resource_remove", "group__pw__resource.html#ga1774043ade001a33ab65e5fbabd5d89e", null ],
     [ "pw_resource_set_bound_id", "group__pw__resource.html#gaf3044f96f645e97035b87d3b37d3e017", null ]
