@@ -1,10 +1,12 @@
 var structfind__data =
 [
+    [ "can_passthrough", "structfind__data.html#a4996d8a089f679dd4df959cafd96958c", null ],
     [ "capture_sink", "structfind__data.html#a2b7e38d1690bd3553701895e3cae7751", null ],
     [ "direction", "structfind__data.html#afa7e864aba90c1a2292b6ce1b9630cb6", null ],
     [ "endpoint", "structfind__data.html#ac7667353b4748b0e32c77954ed1bb3c6", null ],
     [ "ep", "structfind__data.html#ad89e66109793ecedcfcf0b9d0075aa87", null ],
     [ "exclusive", "structfind__data.html#ab46b911258bcdd26cc17f21e986d444c", null ],
+    [ "have_passthrough", "structfind__data.html#a79a0ad671e30842b50981d3005331581", null ],
     [ "id", "structfind__data.html#af8c5ec8ecd723d73c5ab7cea1f01559f", null ],
     [ "impl", "structfind__data.html#a14190842aaa6ddf2d8fd178891c67cff", null ],
     [ "link_group", "structfind__data.html#a1eff0c85b50fb8b7cc53e073027c3f3f", null ],
@@ -12,7 +14,9 @@ var structfind__data =
     [ "name", "structfind__data.html#a1923c4dd37687c42aa18a03135ec34ee", null ],
     [ "node", "structfind__data.html#af788ab09d5cb6a5a261af84c22ec6d91", null ],
     [ "obj", "structfind__data.html#a15e5d651f836350e0532ec2ffd5c841a", null ],
+    [ "passthrough_only", "structfind__data.html#a5d8e36c2b5317125f4810b3d1bc42197", null ],
     [ "plugged", "structfind__data.html#a3d2970e297e27dc72cadb58d3a9d1256", null ],
     [ "priority", "structfind__data.html#a3cd2b07a2ac7d44c32680ed812e51486", null ],
+    [ "result", "structfind__data.html#a79a6e3f8324a9f71b4c1ad9258f0d54f", null ],
     [ "type", "structfind__data.html#a3b660981ae93239e99ba11fd08ebad8d", null ]
 ];
\ No newline at end of file
