@@ -3,6 +3,7 @@ var structimpl =
     [ "aec", "structimpl.html#a0837a6e71a5b2c6e3143f752300897db", null ],
     [ "aec_blocksize", "structimpl.html#a93b91ea7055d8f9e7155653bf31185ce", null ],
     [ "aec_info", "structimpl.html#ac26fa01e794750785d46563dcd2e40c6", null ],
+    [ "alsa_no_dsp", "structimpl.html#aac3b61034d9d4dc42a3752b5a0fc182e", null ],
     [ "avahi_poll", "structimpl.html#af78623f84944d2f3b71a55e1ee5625bf", null ],
     [ "buffer", "structimpl.html#ad17fdf696ec922c4cbce34d2bd3258fd", null ],
     [ "buffer", "structimpl.html#a505b8854b31fb26079be5b1862e0f8f3", null ],
@@ -33,7 +34,7 @@ var structimpl =
     [ "dbus_connection_listener", "structimpl.html#a3b6e1da0cb8a9a57f8039273713f0c9f", null ],
     [ "def", "structimpl.html#abd6be3e875996e4fe65761d5f0c5e022", null ],
     [ "default_sink", "structimpl.html#a87ade71b8089c37fc2e9c21fa5dd5296", null ],
-    [ "defaults", "structimpl.html#a5a6a8be0ab9a0b7c67002be8e00bc713", null ],
+    [ "defaults", "structimpl.html#a82e4463bdc0e298797fdeb80c9c27649", null ],
     [ "device_list", "structimpl.html#a1532d261bda065c5d78e14b5a8fec935", null ],
     [ "do_disconnect", "structimpl.html#a2636d963716d5416478e42586f45f3b3", null ],
     [ "empty", "structimpl.html#a5979042b0f223ba74be9325b9c912bbd", null ],
@@ -56,8 +57,8 @@ var structimpl =
     [ "info", "structimpl.html#afef346d9612a8bb4b83503d60cf42a4d", null ],
     [ "jack_device", "structimpl.html#a3769742eda6c59db596b6bb58587fb7e", null ],
     [ "jack_timeout", "structimpl.html#ae6e0980a83e6935eaae6de5f2191f1d6", null ],
-    [ "ladspa_handle_list", "structimpl.html#adb95ebeb6220e48ae248082878dc6085", null ],
     [ "last_seq", "structimpl.html#a239b920371dc92b5d5916ec323eb43a4", null ],
+    [ "latency_msec", "structimpl.html#a228a1e13d2f6819ca0c5ea2d2dc2a64f", null ],
     [ "link_list", "structimpl.html#a5d792a9e7e7a366e6fa1ea66e9a624c9", null ],
     [ "linking_node_removed", "structimpl.html#a7a3156b7d126f8d602fd35350ddfe956", null ],
     [ "listener", "structimpl.html#a7ebd1744959d08356154b861cfdecbcc", null ],
@@ -87,7 +88,6 @@ var structimpl =
     [ "notify", "structimpl.html#a9e78ebe0bc7f5add8e67bd007386a49b", null ],
     [ "now", "structimpl.html#afd021b1ef9cefa9d07b648aad880a7c3", null ],
     [ "object_list", "structimpl.html#abf04629137334038029a10c7137dee14", null ],
-    [ "old_profiles", "structimpl.html#a4eb2fb2e7634b437a2b51ce33e6876f9", null ],
     [ "out_buffer", "structimpl.html#a11a95793175716af6cf3bf0f82850a8c", null ],
     [ "out_ring", "structimpl.html#a86a3fdde0a2c02e77e86ed6518f591b0", null ],
     [ "out_ringsize", "structimpl.html#ae4c3a1eb35cf40f575015a07bc79e5fe", null ],
@@ -105,6 +105,7 @@ var structimpl =
     [ "playback_info", "structimpl.html#aee7bc2c2013e52765d1cc6eb923196bf", null ],
     [ "playback_listener", "structimpl.html#af0336bcf90fa6f0ecd99e47baf36b41a", null ],
     [ "playback_props", "structimpl.html#a5d82db38fc9ae772e861e8c207de06d8", null ],
+    [ "plugin_list", "structimpl.html#acabb6d0bfdf9e0fe2a76a8e7e7df83a6", null ],
     [ "policy_core", "structimpl.html#aa8dbf75442318ba5e3d97ca72ab7018e", null ],
     [ "policy_listener", "structimpl.html#aaf0df4c738ca1b7651be6bc79c34bbe4", null ],
     [ "portal_pid", "structimpl.html#a3488f95ebe8de133390368484e8c0b1d", null ],
@@ -115,7 +116,7 @@ var structimpl =
     [ "proxy_client_session_listener", "structimpl.html#ae24dfbb8688e72396875adf04c20fb98", null ],
     [ "proxy_policy_listener", "structimpl.html#a083e7825b3594a3e8c70fedd2871c8a5", null ],
     [ "pulse", "structimpl.html#a3666ae085a9b4a92552c2553c01df5e9", null ],
-    [ "rate", "structimpl.html#a7712755f0b74e322cb221f4087c6898d", null ],
+    [ "rate", "structimpl.html#a46c15309500f7d4dc023bdfe1187a2a8", null ],
     [ "rate_match", "structimpl.html#a0e96edc9ecebc4cded609707504a781d", null ],
     [ "rec_buffer", "structimpl.html#a09e83f49e5582480928b929c1d8898f5", null ],
     [ "rec_rate_match", "structimpl.html#ab564ce9ef3e13fdf56ceb78e08714e5c", null ],
@@ -128,6 +129,7 @@ var structimpl =
     [ "rescan_pending", "structimpl.html#a8cfe95911cde55a4393163a36d2d0348", null ],
     [ "rescan_seq", "structimpl.html#a201ba71416b4f1c4d5deee94a904eae2", null ],
     [ "reserve", "structimpl.html#a99e349a85dbb76fb8994ec5dac26a0fc", null ],
+    [ "restore_bluetooth", "structimpl.html#a76a3a9fcaa6ce23a093e1abee76ccb4d", null ],
     [ "restore_timeout", "structimpl.html#ade0c2c61e89b254e3f93867dd5d6d7f6", null ],
     [ "ring", "structimpl.html#a13a90a62b7c51f3ef7ff88bb14b4fa37", null ],
     [ "rt_prio", "structimpl.html#a5adf94afd33ebfd900bb6cf9da557afa", null ],
